/*
 * TeamStats by Mats Bovin (tsppc@mbovin.com)
 * v1.3.0 February 2007
 * Copyright (c) 2004-07 Mats Bovin
 *
 * This file is part of TeamStats.
 *
 * TeamStats is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * TeamStats is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with TeamStats; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

using System;
using System.Net;
using System.Threading;
using MBovin.TeamStats.Util;

namespace MBovin.TeamStats.LiveUpdate
{
    /// <summary>
    /// Class for testing if there is an internet connection available.
    /// </summary>
    public class ConnectionTester : LiveUpdateAsyncBase
    {
        /// <summary>
        /// Constructor
        /// </summary>
        public ConnectionTester() {}

        /// <summary>
        /// Starts a thread that tests if a connection is available.
        /// </summary>
        public void TestConnectionAsync()
        {
            if (!mIsThreadRunning)
            {
                Thread thread = new Thread(new ThreadStart(this.TestConnection));
                thread.Start();
            }
        }

        /// <summary>
        /// Tests the connection and fires LiveUpdate state change events.
        /// </summary>
        private void TestConnection()
        {
            mIsThreadRunning = true;
            
            if (IsConnectionAvailable())
            {
                FireLiveUpdateStateChanged(LiveUpdateEvent.ConnectionOk);
            }
            else
            {
                LogLine(Language.GetString("liveupdate", "noconnection2"));
                FireLiveUpdateStateChanged(LiveUpdateEvent.NoConnection);
            }

            mIsThreadRunning = false;
        }

        /// <summary>
        /// Returns true if there is an internet connection available.
        /// </summary>
        public bool IsConnectionAvailable()
        {
            HttpWebRequest  request  = null;
            HttpWebResponse response = null;
            bool isConnectionAvailable = true;

            try
            {
                // Try to make an http-request to the server
                request = (HttpWebRequest)WebRequest.Create("http://www.aragon.ws");
                request.Timeout = 30000;
                response = (HttpWebResponse)request.GetResponse();
            }
            catch (WebException e)
            {
                // Return false if we get a connection failure
                isConnectionAvailable = (e.Status != WebExceptionStatus.ConnectFailure);
            }
            finally
            {
                if (response != null) response.Close();
            }

            return isConnectionAvailable;
        }      
    }
}
