/*
 * TeamStats by Mats Bovin (tsppc@mbovin.com)
 * v1.3.0 February 2007
 * Copyright (c) 2004-07 Mats Bovin
 *
 * This file is part of TeamStats.
 *
 * TeamStats is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * TeamStats is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with TeamStats; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

using System;
using System.Drawing;
using System.Reflection;
using System.Windows.Forms;
using MBovin.TeamStats.Util;

namespace MBovin.TeamStats.UI
{
	/// <summary>
	/// Summary description for AboutForm.
	/// </summary>
	public class AboutForm : System.Windows.Forms.Form
	{

		/// <summary>
		/// Contructor.
		/// </summary>
        public AboutForm()
		{
			InitializeComponent();
        }

        /// <summary>
        /// Initializes GUI.
        /// </summary>
		private void InitializeComponent()
		{
            int screenHeight = Screen.PrimaryScreen.WorkingArea.Height;

            Label labelName  = new Label();
            labelName.Parent = this;
            labelName.Font   = new System.Drawing.Font("Tahoma", 12F, System.Drawing.FontStyle.Bold);
            labelName.Bounds = new Rectangle(8, 16, 216, 24);
            labelName.Text   = MainForm.cVersion;

            Label labelBuildDate  = new Label();
            labelBuildDate.Parent = this;
            labelBuildDate.Font   = new System.Drawing.Font("Tahoma", 8F, System.Drawing.FontStyle.Regular);
            labelBuildDate.Bounds = new Rectangle(8, 38, 216, 16);
            labelBuildDate.Text   = "Build date: " + GetBuildDate().ToString();

            Label labelCopyright  = new Label();
            labelCopyright.Parent = this;
            labelCopyright.Bounds = new Rectangle(8, 64, 216, 16);
            labelCopyright.Text   = "Copyright (c) 2004-07 Mats Bovin";

            Label labelLicense  = new Label();
            labelLicense.Parent = this;
            labelLicense.Bounds = new Rectangle(8, 82, 232, 36);
            labelLicense.Text   = "TeamStats is distributed under the\nGNU General Public License";

            Label labelWeb  = new Label();
            labelWeb.Parent = this;
            labelWeb.Bounds = new Rectangle(8, 124, 216, 16);
            labelWeb.Text = "http://www.aragon.ws/teamstats";

            Label labelEmail  = new Label();
            labelEmail.Parent = this;
            labelEmail.Bounds = new Rectangle(8, 142, 216, 16);
            labelEmail.Text   = Language.GetString("aboutform", "email") + " tsppc@mbovin.com";

            Label labelVersion  = new Label();
            labelVersion.Parent = this;
            labelVersion.Font   = new System.Drawing.Font("Tahoma", 8F, System.Drawing.FontStyle.Regular);
            labelVersion.Bounds = new Rectangle(150, screenHeight - 41, 90, 24);
            labelVersion.Text   = GetVersionString();

            Button buttonOk       = new Button();
            buttonOk.Parent       = this;
            buttonOk.Font         = MainForm.cButtonFont;
            buttonOk.Bounds       = new Rectangle(8, screenHeight - 36, 60, 20);
            buttonOk.Text         = Language.GetString("aboutform", "ok");
            buttonOk.DialogResult = DialogResult.OK;

            this.FormBorderStyle = System.Windows.Forms.FormBorderStyle.FixedDialog;
            this.ClientSize      = new System.Drawing.Size(234, screenHeight - 6);
            this.Text            = Language.GetString("aboutform", "title") + " TeamStats";
        }

        /// <summary>
        /// Returns the build date of the assembly.
        /// </summary>
        private DateTime GetBuildDate()       
        {
            Version version = Assembly.GetExecutingAssembly().GetName().Version;
            DateTime buildDate = new DateTime(2000, 1, 1);
            // Build is number of days since 2000-01-01
            buildDate = buildDate.AddDays(version.Build);
            // Revision is number of seconds since midninght / 2
            buildDate = buildDate.AddSeconds(version.Revision * 2);
            return buildDate;
        }

        /// <summary>
        /// Returns a string with os and clr versions
        /// </summary>
        private string GetVersionString()
        {
            Version clrVersion = System.Environment.Version;
            Version osVersion  = System.Environment.OSVersion.Version;

            return string.Format("OS: {0}.{1}.{2}\r\nCLR: {3}.{4}.{5}.{6}",
                osVersion.Major, osVersion.Minor, osVersion.Build,
                clrVersion.Major, clrVersion.Minor, clrVersion.Build, clrVersion.Revision);
        }
 	}
}
