/*
 * TeamStats by Mats Bovin (tsppc@mbovin.com)
 * v1.3.0 February 2007
 * Copyright (c) 2004-07 Mats Bovin
 *
 * This file is part of TeamStats.
 *
 * TeamStats is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * TeamStats is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with TeamStats; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

using System;
using System.Drawing;
using System.Collections;
using System.Windows.Forms;
using MBovin.TeamStats;
using MBovin.TeamStats.Controls;
using MBovin.TeamStats.Core;
using MBovin.TeamStats.Util;

namespace MBovin.TeamStats.UI
{
	/// <summary>
	/// A form for editing fixtures.
	/// </summary>
	public class FixtureForm : System.Windows.Forms.Form
	{
        private MainMenu mMainMenu1;
        private MenuItem mMenuItemEdit;
        private MenuItem mMenuItemAddRound;
        private MenuItem mMenuItemDeleteRound;
        private MenuItem mMenuItemDeleteMatch;
        private Label mLabelRound;
        private Button mButtonPrevRound;
        private Button mButtonNextRound;
        private DateTimePicker mDateTimePickerMatchDate;
        private ComboBox mComboBoxHomeTeam;
        private ComboBox mComboBoxAwayTeam;
        private Button mButtonAddMatch;
        private ListBox mListBoxMatches;
        private Button mButtonClose;

        private AppState mAppState;
        private int mRound;


        /// <summary>
        /// Constructor
        /// </summary>
        public FixtureForm(AppState appState)
        {
            mAppState = appState;

            InitializeComponent();
        }

        #region Windows Form Designer generated code
        /// <summary>
        /// Required method for Designer support - do not modify
        /// the contents of this method with the code editor.
        /// </summary>
        private void InitializeComponent()
        {
            int screenHeight = Screen.PrimaryScreen.WorkingArea.Height;

            Graphics g = CreateGraphics();
            int width;

            this.mLabelRound = new System.Windows.Forms.Label();
            this.mButtonPrevRound = new System.Windows.Forms.Button();
            this.mButtonNextRound = new System.Windows.Forms.Button();
            this.mComboBoxHomeTeam = new System.Windows.Forms.ComboBox();
            this.mComboBoxAwayTeam = new System.Windows.Forms.ComboBox();
            this.mButtonAddMatch = new System.Windows.Forms.Button();
            this.mListBoxMatches = new System.Windows.Forms.ListBox();
            this.mMainMenu1 = new System.Windows.Forms.MainMenu();
            this.mMenuItemEdit = new System.Windows.Forms.MenuItem();
            this.mMenuItemAddRound = new System.Windows.Forms.MenuItem();
            this.mMenuItemDeleteRound = new System.Windows.Forms.MenuItem();
            this.mMenuItemDeleteMatch = new System.Windows.Forms.MenuItem();
            this.mButtonClose = new System.Windows.Forms.Button();
            // 
            // mainMenu1
            // 
            this.mMainMenu1.MenuItems.Add(this.mMenuItemEdit);
            // 
            // menuItemEdit
            // 
            this.mMenuItemEdit.MenuItems.Add(this.mMenuItemAddRound);
            this.mMenuItemEdit.MenuItems.Add(this.mMenuItemDeleteRound);
            this.mMenuItemEdit.MenuItems.Add(this.mMenuItemDeleteMatch);
            this.mMenuItemEdit.Text = Language.GetString("fixtureform", "edit");
            // 
            // menuItemAddRound
            // 
            this.mMenuItemAddRound.Text   = Language.GetString("fixtureform", "addround");
            this.mMenuItemAddRound.Click += new System.EventHandler(this.MenuItemAddRound_Click);
            // 
            // menuItemDeleteRound
            // 
            this.mMenuItemDeleteRound.Text   = Language.GetString("fixtureform", "deleteround");
            this.mMenuItemDeleteRound.Click += new System.EventHandler(this.MenuItemDeleteRound_Click);
            // 
            // menuItemDeleteMatch
            // 
            this.mMenuItemDeleteMatch.Text   = Language.GetString("fixtureform", "deletematch");
            this.mMenuItemDeleteMatch.Click += new System.EventHandler(this.MenuItemDeleteMatch_Click);
            // 
            // labelRound
            // 
            this.mLabelRound.Parent = this;
            this.mLabelRound.Bounds = new Rectangle(90, 1, 60, 16);
            this.mLabelRound.Font   = new Font("Tahoma", 9F, FontStyle.Underline);

            // Font used by prev and next buttons
            // We want to use Bookdings to display arrow symbols but if it's
            // not available we use Tahoma and < and > chars instead.
            Font prevNextFont = new Font("Bookdings", 12F, FontStyle.Regular);
            bool isBookdingsAvailable = (prevNextFont.Name == "Bookdings");
            if (!isBookdingsAvailable)
            {
                prevNextFont = new Font("Tahoma", 10F, FontStyle.Regular);
            }

            // 
            // buttonPrevRound
            // 
            this.mButtonPrevRound.Parent = this;
            this.mButtonPrevRound.Bounds = new Rectangle(66, 2, 15, 15);
            this.mButtonPrevRound.Font   = prevNextFont;
            this.mButtonPrevRound.Text   = (isBookdingsAvailable) ? "3" : "<"; // "3" will display an arrow symbol
            this.mButtonPrevRound.Click += new System.EventHandler(this.ButtonPrevRound_Click);
            // 
            // buttonNextRound
            // 
            this.mButtonNextRound.Parent = this;
            this.mButtonNextRound.Bounds = new Rectangle(150, 2, 15, 15);
            this.mButtonNextRound.Font   = prevNextFont;
            this.mButtonNextRound.Text   = (isBookdingsAvailable) ? "4" : ">"; // "4" will display an arrow symbol
            this.mButtonNextRound.Click += new System.EventHandler(this.ButtonNextRound_Click);
            //
            // dateTimePickerMatchDate
            //
            this.mDateTimePickerMatchDate        = new DateTimePicker();
            this.mDateTimePickerMatchDate.Parent = this;
            this.mDateTimePickerMatchDate.Bounds = new Rectangle(4, 20, 49, 20);
            // 
            // comboBoxHomeTeam
            // 
            this.mComboBoxHomeTeam.Parent = this;
            this.mComboBoxHomeTeam.Bounds = new Rectangle(57, 20, 88, 21);
            // 
            // comboBoxAwayTeam
            // 
            this.mComboBoxAwayTeam.Parent = this;
            this.mComboBoxAwayTeam.Bounds = new Rectangle(149, 20, 88, 21);
            // 
            // buttonAddMatch
            // 
            this.mButtonAddMatch.Parent = this;
            this.mButtonAddMatch.Font   = MainForm.cButtonFont;
            this.mButtonAddMatch.Text   = Language.GetString("fixtureform", "addmatch");
            width = (int)g.MeasureString(this.mButtonAddMatch.Text, this.mButtonAddMatch.Font).Width + 14;
            this.mButtonAddMatch.Bounds = new Rectangle(this.ClientSize.Width - 8 - width, 44, width, 20);
            this.mButtonAddMatch.Click += new System.EventHandler(this.ButtonAddMatch_Click);
            // 
            // listBoxMatches
            // 
            this.mListBoxMatches.Parent = this;
            this.mListBoxMatches.Bounds = new Rectangle(8, 74, 224, screenHeight - 136);
            // 
            // buttonClose
            // 
            this.mButtonClose.Parent = this;
            this.mButtonClose.Bounds = new Rectangle(8, screenHeight - 56, 60, 20);
            this.mButtonClose.Font   = MainForm.cButtonFont;
            this.mButtonClose.Text   = Language.GetString("fixtureform", "close");
            this.mButtonClose.DialogResult = DialogResult.OK;
            // 
            // FixtureForm
            // 
            this.Menu  = this.mMainMenu1;
            this.Text  = Language.GetString("fixtureform", "title");
            this.Load += new System.EventHandler(this.FixtureForm_Load);

            g.Dispose();
        }
        #endregion

        #region Events

        /// <summary>
        /// Intialize the form.
        /// </summary>
        private void FixtureForm_Load(object sender, System.EventArgs e)
        {
            League league = mAppState.CurrentLeague;
            
            FillTeamComboBoxes(league);
            GoToRound(league.RoundCount);
        }

        /// <summary>
        /// The next round button is clicked.
        /// </summary>
        private void ButtonNextRound_Click(object sender, System.EventArgs e)
        {
            League league = mAppState.CurrentLeague;
            if (mRound < league.RoundCount)
            {
                GoToRound(mRound + 1);
            }
        }

        /// <summary>
        /// The previous round button is clicked.
        /// </summary>
        private void ButtonPrevRound_Click(object sender, System.EventArgs e)
        {
            if (mRound > 1)
            {
                GoToRound(mRound - 1);
            }
        }
        
        /// <summary>
        /// Adds a match to the league.
        /// </summary>
        private void ButtonAddMatch_Click(object sender, EventArgs e)
        {
            int homeTeamIndex = ((Team)mComboBoxHomeTeam.SelectedItem).Index;
            int awayTeamIndex = ((Team)mComboBoxAwayTeam.SelectedItem).Index;
            League league = mAppState.CurrentLeague;

            if (homeTeamIndex != awayTeamIndex)
            {
                Match match = new Match(league, 
                    mRound, 
                    mDateTimePickerMatchDate.Value, 
                    homeTeamIndex, 
                    awayTeamIndex);

                league.AddMatch(match);
            }

            GoToRound(mRound);
        }

        /// <summary>
        /// Adds a round to the league.
        /// </summary>
        private void MenuItemAddRound_Click(object sender, EventArgs e)
        {
            League league = mAppState.CurrentLeague;
            league.AddRound();
            GoToRound(league.RoundCount);
        }

        /// <summary>
        /// Tries to delete the current round. Only the last round
        /// can be deleted and only if it doesn't contain any matches.
        /// </summary>
        private void MenuItemDeleteRound_Click(object sender, EventArgs e)
        {
            League league = mAppState.CurrentLeague;
            if (mRound == 1)
            {
                MessageBox.Show(Language.GetString("fixtureform", "cannotdeletefirst"),
                                "Guru Meditation", 
                                MessageBoxButtons.OK, 
                                MessageBoxIcon.Hand, 
                                MessageBoxDefaultButton.Button1);
            }
            else if (mRound < league.RoundCount)
            {
                MessageBox.Show(Language.GetString("fixtureform", "onlydeletelast"),
                                "Guru Meditation", 
                                MessageBoxButtons.OK, 
                                MessageBoxIcon.Hand, 
                                MessageBoxDefaultButton.Button1);
            }
            else if (mListBoxMatches.Items.Count > 0)
            {
                MessageBox.Show(Language.GetString("fixtureform", "onlydeleteempty"),
                                "Guru Meditation", 
                                MessageBoxButtons.OK, 
                                MessageBoxIcon.Hand, 
                                MessageBoxDefaultButton.Button1);
            }
            else
            {
                league.DeleteLastRound();
                GoToRound(mRound-1);
            }                
        }

        /// <summary>
        /// Deletes the currently selected match.
        /// </summary>
        private void MenuItemDeleteMatch_Click(object sender, EventArgs e)
        {
            if (mListBoxMatches.SelectedIndex != -1)
            {
                Match match = (Match)mListBoxMatches.SelectedItem;
                mAppState.CurrentLeague.DeleteMatch(match);
                GoToRound(mRound);
            }
            else
            {
                MessageBox.Show(Language.GetString("fixtureform", "selectmatch"), 
                                "Guru Meditation",  
                                MessageBoxButtons.OK, 
                                MessageBoxIcon.Hand,
                                MessageBoxDefaultButton.Button1);
            }
        }

        /// <summary>
        /// Handles tapping on the round label.
        /// </summary>
        protected override void OnMouseUp(MouseEventArgs e)
        {
            base.OnMouseUp(e);

            if (e.X > (this.ClientSize.Width / 2 - 30)  && e.X < (this.ClientSize.Width / 2 + 25)
                && e.Y > 1 && e.Y < 17)
            {                
                // Show the "Select round:" dialog
                SelectRoundForm roundForm = new SelectRoundForm(mAppState.CurrentLeague.RoundCount);
                roundForm.ShowDialog();

                // Show the new round if on was selected
                if (roundForm.SelectedRound > -1)
                {
                    GoToRound(roundForm.SelectedRound);
                }
            }
        }

        #endregion

        /// <summary>
        /// Fills the comboboxes with teams.
        /// </summary>
        private void FillTeamComboBoxes(League league)
        {
            ArrayList teamList = league.GetTeams();

            // Sort the teams alphabetically
            teamList.Sort();
            
            // Clear list and add the teams
            mComboBoxHomeTeam.Items.Clear();
            mComboBoxAwayTeam.Items.Clear();
            foreach (Team team in teamList)
            {
                mComboBoxHomeTeam.Items.Add(team);
                mComboBoxAwayTeam.Items.Add(team);
            }

            mComboBoxHomeTeam.SelectedIndex = 0;
            mComboBoxAwayTeam.SelectedIndex = 1;
        }

        /// <summary>
        /// Fills the match listbox with matches for the current round.
        /// </summary>
        private void FillMatchListBox()
        {
            League league       = mAppState.CurrentLeague;
            ArrayList matchList = league.GetMatchesForRound(mRound);
            
            mListBoxMatches.Items.Clear();
            foreach (Match match in matchList)
            {
                mListBoxMatches.Items.Add(match);
            }
        }
        
        /// <summary>
        /// Displays the specified round.
        /// </summary>
        private void GoToRound(int round)
        {
            mRound = round;
            FillMatchListBox();

            mLabelRound.Text = Language.GetString("fixtureform", "round") + mRound;
            Graphics g = CreateGraphics();
            mLabelRound.Width = (int)g.MeasureString(mLabelRound.Text, mLabelRound.Font).Width + 2;
            g.Dispose();
            mLabelRound.Left = (this.ClientSize.Width - mLabelRound.Width) / 2;
            mButtonPrevRound.Left = mLabelRound.Left - mButtonPrevRound.Width - 6;
            mButtonNextRound.Left = mLabelRound.Right + 6;
        }
    }
}
