/*
 * TeamStats by Mats Bovin (tsppc@mbovin.com)
 * v1.3.0 February 2007
 * Copyright (c) 2004-07 Mats Bovin
 *
 * This file is part of TeamStats.
 *
 * TeamStats is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * TeamStats is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with TeamStats; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

using System;
using System.Drawing;
using System.IO;
using System.Windows.Forms;
using Microsoft.WindowsCE.Forms;
using MBovin.TeamStats;
using MBovin.TeamStats.Core;
using MBovin.TeamStats.Util;

namespace MBovin.TeamStats.UI
{
    /// <summary>
    /// Enumeration for the two modes of the LeaeguForm
    /// </summary>
    public enum LeagueFormMode
    {
        New,
        Edit
    }

    /// <summary>
    /// A form for creating new leagues and for editing league data.
    /// </summary>
    public class LeagueForm : System.Windows.Forms.Form
    {        
        private System.Windows.Forms.MainMenu mMainMenu1;        
        private System.Windows.Forms.Label mLabelLeagueName;
        private System.Windows.Forms.TextBox mTextBoxLeagueName;
        private System.Windows.Forms.Label mLabelSeason;
        private System.Windows.Forms.NumericUpDown mNumericUpDownSeason;
        private System.Windows.Forms.CheckBox mCheckBoxIsSplit;
        private System.Windows.Forms.Label mLabelTeamCount;
        private System.Windows.Forms.TextBox mTextBoxTeamCount;
        private System.Windows.Forms.Label mLabelWinPoints;
        private System.Windows.Forms.TextBox mTextBoxWinPoints;
        private System.Windows.Forms.Label mLabelDrawPoints;
        private System.Windows.Forms.TextBox mTextBoxDrawPoints;
        private System.Windows.Forms.Label mLabelLossPoints;
        private System.Windows.Forms.TextBox mTextBoxLossPoints;
        private System.Windows.Forms.Label mLabelTableSort;
        private System.Windows.Forms.ComboBox mComboBoxTableSort;
        private System.Windows.Forms.Label mLabelTableLines;
        private System.Windows.Forms.ComboBox mComboBoxLine1;
        private System.Windows.Forms.ComboBox mComboBoxLine3;
        private System.Windows.Forms.ComboBox mComboBoxLine2;
        private System.Windows.Forms.ComboBox mComboBoxLine4;
        private System.Windows.Forms.Button mButtonOK;
        private System.Windows.Forms.Button mButtonCancel;

        private LeagueFormMode mMode;
        private AppState       mAppState;
        private InputPanel     mSip;
        private string         mSelectedLeagueName;
        private string         mSelectedSeason;

    
        /// <summary>
        /// Constructor
        /// </summary>
        public LeagueForm(LeagueFormMode mode, AppState appState)
        {
            mMode     = mode;
            mAppState = appState;
            mSip      = new InputPanel();

            InitializeComponent();
        }

        #region Windows Form Designer generated code
        /// <summary>
        /// Required method for Designer support - do not modify
        /// the contents of this method with the code editor.
        /// </summary>
        private void InitializeComponent()
        {
            Graphics g = CreateGraphics();
            int width;

            this.mMainMenu1 = new System.Windows.Forms.MainMenu();
            this.mLabelLeagueName = new System.Windows.Forms.Label();
            this.mTextBoxLeagueName = new System.Windows.Forms.TextBox();
            this.mLabelSeason = new System.Windows.Forms.Label();
            this.mNumericUpDownSeason = new System.Windows.Forms.NumericUpDown();
            this.mCheckBoxIsSplit = new System.Windows.Forms.CheckBox();
            this.mLabelTeamCount = new System.Windows.Forms.Label();
            this.mTextBoxTeamCount = new System.Windows.Forms.TextBox();
            this.mLabelWinPoints = new System.Windows.Forms.Label();
            this.mTextBoxWinPoints = new System.Windows.Forms.TextBox();
            this.mTextBoxDrawPoints = new System.Windows.Forms.TextBox();
            this.mLabelDrawPoints = new System.Windows.Forms.Label();
            this.mTextBoxLossPoints = new System.Windows.Forms.TextBox();
            this.mLabelLossPoints = new System.Windows.Forms.Label();
            this.mLabelTableLines = new System.Windows.Forms.Label();
            this.mComboBoxTableSort = new System.Windows.Forms.ComboBox();
            this.mLabelTableSort = new System.Windows.Forms.Label();
            this.mComboBoxLine1 = new System.Windows.Forms.ComboBox();
            this.mComboBoxLine3 = new System.Windows.Forms.ComboBox();
            this.mComboBoxLine2 = new System.Windows.Forms.ComboBox();
            this.mComboBoxLine4 = new System.Windows.Forms.ComboBox();
            this.mButtonOK = new System.Windows.Forms.Button();
            this.mButtonCancel = new System.Windows.Forms.Button();
            // 
            // labelLeagueName
            // 
            this.mLabelLeagueName.Parent = this;
            this.mLabelLeagueName.Text = Language.GetString("leagueform", "leaguename");
            width = (int)g.MeasureString(this.mLabelLeagueName.Text, this.mLabelLeagueName.Font).Width + 2;
            this.mLabelLeagueName.Bounds = new Rectangle(2, 4, width, 16);
            // 
            // textBoxLeagueName
            // 
            this.mTextBoxLeagueName.Parent = this;
            this.mTextBoxLeagueName.Bounds = new Rectangle(
                this.mLabelLeagueName.Right + 2, 
                1,
                this.ClientSize.Width - 4 - (this.mLabelLeagueName.Right + 2),
                20);
            this.mTextBoxLeagueName.MaxLength = 16;
            this.mTextBoxLeagueName.Text      = "";
            // 
            // labelSeason
            // 
            this.mLabelSeason.Parent = this;
            this.mLabelSeason.Text   = Language.GetString("leagueform", "season");
            width = (int)g.MeasureString(this.mLabelSeason.Text, this.mLabelSeason.Font).Width + 2;
            this.mLabelSeason.Bounds = new Rectangle(2, 28, width, 16);
            // 
            // numericUpDownSeason
            // 
            this.mNumericUpDownSeason.Parent   = this;
            this.mNumericUpDownSeason.Bounds   = new Rectangle(this.mLabelSeason.Right + 2, 25, 69, 20);
            this.mNumericUpDownSeason.Maximum  = new System.Decimal(new int[] { 9999, 0, 0, 0});
            this.mNumericUpDownSeason.Minimum  = new System.Decimal(new int[] { 1000, 0, 0, 0});
            this.mNumericUpDownSeason.ReadOnly = true;
            this.mNumericUpDownSeason.Value    = new System.Decimal(new int[] { 1000, 0, 0, 0});
            // 
            // checkBoxIsSplit
            // 
            this.mCheckBoxIsSplit.Parent = this;
            this.mCheckBoxIsSplit.Bounds = new Rectangle(4, 49, 230, 16);
            this.mCheckBoxIsSplit.Text   = Language.GetString("leagueform", "split");
            // 
            // labelTeamCount
            // 
            this.mLabelTeamCount.Parent = this;
            this.mLabelTeamCount.Text   = Language.GetString("leagueform", "numberofteams");
            width = (int)g.MeasureString(this.mLabelTeamCount.Text, this.mLabelTeamCount.Font).Width + 2;
            this.mLabelTeamCount.Bounds = new Rectangle(2, 69, width, 14);
            // 
            // textBoxTeamCount
            // 
            this.mTextBoxTeamCount.Parent       = this;
            this.mTextBoxTeamCount.Bounds       = new Rectangle(this.mLabelTeamCount.Right + 2, 66, 24, 20);
            this.mTextBoxTeamCount.MaxLength    = 2;
            this.mTextBoxTeamCount.Text         = "";
            this.mTextBoxTeamCount.KeyPress    += new System.Windows.Forms.KeyPressEventHandler(this.TextBoxNumeric_KeyPress);
            this.mTextBoxTeamCount.TextChanged += new System.EventHandler(this.TextBoxTeamCount_TextChanged);
            // 
            // labelWinPoints
            // 
            this.mLabelWinPoints.Parent = this;
            this.mLabelWinPoints.Text   = Language.GetString("leagueform", "pointswin");
            width = (int)g.MeasureString(this.mLabelWinPoints.Text, this.mLabelWinPoints.Font).Width + 2;
            this.mLabelWinPoints.Bounds = new Rectangle(2, 92, width, 16);
            // 
            // textBoxWinPoints
            // 
            this.mTextBoxWinPoints.Parent    = this;
            this.mTextBoxWinPoints.Bounds    = new Rectangle(this.mLabelWinPoints.Right + 2, 89, 24, 20);
            this.mTextBoxWinPoints.MaxLength = 2;
            this.mTextBoxWinPoints.Text      = "";
            this.mTextBoxWinPoints.KeyPress += new System.Windows.Forms.KeyPressEventHandler(this.TextBoxNumeric_KeyPress);
            // 
            // labelDrawPoints
            // 
            this.mLabelDrawPoints.Parent = this;
            this.mLabelDrawPoints.Text   = Language.GetString("leagueform", "pointsdraw");
            width = (int)g.MeasureString(this.mLabelDrawPoints.Text, this.mLabelDrawPoints.Font).Width + 2;
            this.mLabelDrawPoints.Bounds = new Rectangle(this.mTextBoxWinPoints.Right + 2, 92, width, 16);
            // 
            // textBoxDrawPoints
            // 
            this.mTextBoxDrawPoints.Parent    = this;
            this.mTextBoxDrawPoints.Bounds    = new Rectangle(this.mLabelDrawPoints.Right + 2, 89, 24, 20);
            this.mTextBoxDrawPoints.MaxLength = 2;
            this.mTextBoxDrawPoints.Text      = "";
            this.mTextBoxDrawPoints.KeyPress += new System.Windows.Forms.KeyPressEventHandler(this.TextBoxNumeric_KeyPress);
            // 
            // labelLossPoints
            // 
            this.mLabelLossPoints.Parent = this;
            this.mLabelLossPoints.Text   = Language.GetString("leagueform", "pointsloss");
            width = (int)g.MeasureString(this.mLabelLossPoints.Text, this.mLabelLossPoints.Font).Width + 2;
            this.mLabelLossPoints.Bounds = new Rectangle(this.mTextBoxDrawPoints.Right + 2, 92, width, 16);
            // 
            // textBoxLossPoints
            // 
            this.mTextBoxLossPoints.Parent    = this;
            this.mTextBoxLossPoints.Bounds    = new Rectangle(this.mLabelLossPoints.Right + 2, 89, 24, 20);
            this.mTextBoxLossPoints.MaxLength = 2;
            this.mTextBoxLossPoints.Text      = "";
            this.mTextBoxLossPoints.KeyPress += new System.Windows.Forms.KeyPressEventHandler(this.TextBoxNumeric_KeyPress);
            // 
            // labelTableSort
            // 
            this.mLabelTableSort.Parent = this;
            this.mLabelTableSort.Text   = Language.GetString("leagueform", "sorttable");
            width = (int)g.MeasureString(this.mLabelTableSort.Text, this.mLabelTableSort.Font).Width + 2;
            this.mLabelTableSort.Bounds = new Rectangle(2, 117, width, 15);
            // 
            // comboBoxTableSort
            // 
            this.mComboBoxTableSort.Parent = this;
            this.mComboBoxTableSort.Bounds = new Rectangle(
                this.mLabelTableSort.Right + 2, 
                114, 
                this.ClientSize.Width - 4 - (this.mLabelTableSort.Right + 2),
                21);
            this.mComboBoxTableSort.Items.Add(Language.GetString("leagueform", "goaldiffgoals"));
            this.mComboBoxTableSort.Items.Add(Language.GetString("leagueform", "goaldiffwins"));
            this.mComboBoxTableSort.Items.Add(Language.GetString("leagueform", "winsgoaldiff"));
            this.mComboBoxTableSort.Items.Add(Language.GetString("leagueform", "winsgoals"));
            this.mComboBoxTableSort.Items.Add(Language.GetString("leagueform", "goalsgoaldiff"));
            this.mComboBoxTableSort.Items.Add(Language.GetString("leagueform", "goalswins"));
            // 
            // labelTableLines
            // 
            this.mLabelTableLines.Parent = this;
            this.mLabelTableLines.Text   = Language.GetString("leagueform", "lines");
            width = (int)g.MeasureString(this.mLabelTableLines.Text, this.mLabelTableLines.Font).Width + 2;
            this.mLabelTableLines.Bounds = new Rectangle(2, 142, width, 16);
            // 
            // comboBoxLine1
            // 
            this.mComboBoxLine1.Parent = this;
            this.mComboBoxLine1.Bounds = new Rectangle(this.mLabelTableLines.Right + 2, 139, 32, 21);
            // 
            // comboBoxLine2
            // 
            this.mComboBoxLine2.Parent = this;
            this.mComboBoxLine2.Bounds = new Rectangle(this.mComboBoxLine1.Right + 2, 139, 32, 21);
            // 
            // comboBoxLine3
            // 
            this.mComboBoxLine3.Parent = this;
            this.mComboBoxLine3.Bounds = new Rectangle(this.mComboBoxLine2.Right + 2, 139, 32, 21);
            // 
            // comboBoxLine4
            // 
            this.mComboBoxLine4.Parent = this;
            this.mComboBoxLine4.Bounds = new Rectangle(this.mComboBoxLine3.Right + 2, 139, 32, 21);
            // 
            // buttonOK
            // 
            this.mButtonOK.Parent = this;
            this.mButtonOK.Text   = Language.GetString("leagueform", "ok");
            this.mButtonOK.Font   = MainForm.cButtonFont;
            this.mButtonOK.Bounds = new Rectangle(8, 165, 60, 20);
            this.mButtonOK.DialogResult = DialogResult.OK;
            // 
            // buttonCancel
            // 
            this.mButtonCancel.Parent = this;
            this.mButtonCancel.Text   = Language.GetString("leagueform", "cancel");
            this.mButtonCancel.Font   = MainForm.cButtonFont;
            this.mButtonCancel.Bounds = new Rectangle(76, 165, 60, 20);
            this.mButtonCancel.DialogResult = DialogResult.Cancel;
            // 
            // LeagueForm
            // 
            this.ClientSize = new System.Drawing.Size(240, 192);
            this.Menu = this.mMainMenu1;
            this.Text = "LeagueForm";
            this.Closing += new System.ComponentModel.CancelEventHandler(this.LeagueForm_Closing);
            this.Load    += new System.EventHandler(this.LeagueForm_Load);
            // The following is so that the ok-button in the 
            // top-right corner returns OK.
            this.DialogResult = DialogResult.OK;

            g.Dispose();
        }
        #endregion
        
        #region Properties

        /// <summary>
        /// The name of the league created or edited in this form.
        /// If DialogResult == Cancel this property will return null.
        /// </summary>
        public string SelectedLeagueName
        {
            get { return mSelectedLeagueName; }
        }

        /// <summary>
        /// The season created or edited in this form.
        /// If DialogResult == Cancel this property will return null.
        /// </summary>
        public string SelectedSeason
        {
            get { return mSelectedSeason; }
        }
        
        #endregion 

        #region Events

        /// <summary>
        /// Intialize the form.
        /// </summary>
        private void LeagueForm_Load(object sender, System.EventArgs e)
        {
            // If edit -> copy existing values to controls
            if (mMode == LeagueFormMode.Edit)
            {
                this.Text = Language.GetString("leagueform", "titleedit");

                League league = mAppState.CurrentLeague;

                mTextBoxLeagueName.Text          = league.Name;
                mNumericUpDownSeason.Value       = league.Year;
                mCheckBoxIsSplit.Checked         = league.IsSplit;
                mTextBoxWinPoints.Text           = league.WinPoints.ToString();
                mTextBoxDrawPoints.Text          = league.DrawPoints.ToString();
                mTextBoxLossPoints.Text          = league.LossPoints.ToString();
                mComboBoxTableSort.SelectedIndex = (int)league.TableSort;
                
                FillTableLineCombos(league.TeamCount);

                int[] tableLines = league.GetTableLines();
                mComboBoxLine1.SelectedIndex = (tableLines.Length > 0) ? tableLines[0] : 0;
                mComboBoxLine2.SelectedIndex = (tableLines.Length > 1) ? tableLines[1] : 0;
                mComboBoxLine3.SelectedIndex = (tableLines.Length > 2) ? tableLines[2] : 0;
                mComboBoxLine4.SelectedIndex = (tableLines.Length > 3) ? tableLines[3] : 0;

                mLabelTeamCount.Hide();
                mTextBoxTeamCount.Hide();
            }
            // If new -> set default values in controls
            else //mMode == LeagueFormMode.New
            {
                this.Text = Language.GetString("leagueform", "titlenew");

                mNumericUpDownSeason.Value       = DateTime.Now.Year;
                mCheckBoxIsSplit.Checked         = true;
                mTextBoxWinPoints.Text           = "3";
                mTextBoxDrawPoints.Text          = "1";
                mTextBoxLossPoints.Text          = "0";
                mComboBoxTableSort.SelectedIndex = (int)TableSortMethod.GoalDiff_GoalsFor;
                FillTableLineCombos(0);
            }

            // We only open the input panel if we're on a 320 high screen
            if (Screen.PrimaryScreen.WorkingArea.Height >= 294)
            {
                mSip.Enabled = true;
            }
            mTextBoxLeagueName.Focus();
        }

        /// <summary>
        /// Handles saving and closing.
        /// </summary>
        private void LeagueForm_Closing(object sender, System.ComponentModel.CancelEventArgs e)
        {
            if (this.DialogResult == DialogResult.OK)
            {
                e.Cancel = !ValidateAndSave();
            }
            
            if (!e.Cancel)
            {
                mSip.Enabled = false;
            }
        }

        /// <summary>
        /// Updates the table lines combo boxes when number of teams is changed.
        /// </summary>
        private void TextBoxTeamCount_TextChanged(object sender, System.EventArgs e)
        {
            int teamCount = Utils.StringToInt32(mTextBoxTeamCount.Text, 0);
            FillTableLineCombos(teamCount);
        }

        /// <summary>
        /// A charcater is entered in one of the numeric text boxes.
        /// Checks that it's a digit or backspace.
        /// </summary>
        private void TextBoxNumeric_KeyPress(object sender, KeyPressEventArgs e)
        {
            if (!(Char.IsDigit(e.KeyChar) || e.KeyChar == 8))
            {
                e.Handled = true;
            }
        }

        #endregion

        /// <summary>
        /// Inserts items in the table line combo boxes.
        /// </summary>
        private void FillTableLineCombos(int teamCount)
        {
            mComboBoxLine1.Items.Clear();
            mComboBoxLine2.Items.Clear();
            mComboBoxLine3.Items.Clear();
            mComboBoxLine4.Items.Clear();

            mComboBoxLine1.Items.Add("-");
            mComboBoxLine2.Items.Add("-");
            mComboBoxLine3.Items.Add("-");
            mComboBoxLine4.Items.Add("-");

            mComboBoxLine1.SelectedIndex = 0;
            mComboBoxLine2.SelectedIndex = 0;
            mComboBoxLine3.SelectedIndex = 0;
            mComboBoxLine4.SelectedIndex = 0;

            for (int i = 0; i < teamCount; i++)
            {
                mComboBoxLine1.Items.Add(i+1);
                mComboBoxLine2.Items.Add(i+1);
                mComboBoxLine3.Items.Add(i+1);
                mComboBoxLine4.Items.Add(i+1);
            }
        }

        /// <summary>
        /// Checks the name for invalid characters. Returns true
        /// if name is ok, false otherwise.
        /// </summary>
        private bool ValidateLeagueName(string name)
        {
            char[] invalidChars = { Path.PathSeparator, 
                                    Path.VolumeSeparatorChar, 
                                    Path.AltDirectorySeparatorChar, 
                                    Path.DirectorySeparatorChar,
                                    '*',
                                    '?'};

            return ((name.IndexOfAny(Path.InvalidPathChars) == -1) && 
                    (name.IndexOfAny(invalidChars) == -1));
        }

        /// <summary>
        /// Validates the form and displays error message if some data
        /// is missing or wrong. If everything is ok the league is saved.
        /// </summary>
        /// <returns>Returns true if all input is ok and the league was saved, false otherwise.</returns>
        private bool ValidateAndSave()
        {
            // Make sure the league has a name
            if (mTextBoxLeagueName.Text.Trim().Length == 0)
            {
                // "The league must have a name."
                MessageBox.Show(Language.GetString("leagueform", "musthavename"), "Guru Meditation");
                mTextBoxLeagueName.Focus();
                return false;
            }
            
            // Make sure characters are valid (the league name is included 
            // in the filename.
            if(!ValidateLeagueName(mTextBoxLeagueName.Text.Trim()))
            {
                //"The league name contains invalid characters."
                MessageBox.Show(Language.GetString("leagueform", "invalidchars"), "Guru Meditation");
                mTextBoxLeagueName.Focus();
                return false;
            }

            League league;
            string filename = LeagueBinaryFile.CreateFullFilename(
                mTextBoxLeagueName.Text.Trim(), 
                (int)mNumericUpDownSeason.Value, 
                mCheckBoxIsSplit.Checked);

            if (mMode == LeagueFormMode.New)
            {
                // Check number of teams
                int teamCount = Utils.StringToInt32(mTextBoxTeamCount.Text, 0);
                if (teamCount < 2 || teamCount > 32)
                {
                    // "The league can have between 2 and 32 teams."
                    MessageBox.Show(Language.GetString("leagueform", "invalidteams"), "Guru Meditation");
                    mTextBoxTeamCount.Focus();
                    return false;
                }

                if (LeagueBinaryFile.IsFilenameAvailable(filename))
                {
                    league = new League();
                    league.LeagueStore = new LeagueBinaryFile(filename);
                }
                else
                {
                    // "The league name is already used. Try a different name or season."
                    MessageBox.Show(Language.GetString("leagueform", "namealreadyused"), "Guru Meditation");
                    mTextBoxLeagueName.Focus();
                    return false;
                }
            }
            else // mMode = LeagueFormMode.Edit
            {
                league = mAppState.CurrentLeague;

                try
                {
                    // Tries to rename the current league file
                    ((LeagueBinaryFile)league.LeagueStore).Rename(filename);
                }
                catch (System.IO.IOException)
                {
                    // "The league name is already used. Try a different name or season."
                    MessageBox.Show(Language.GetString("leagueform", "namealreadyused"), "Guru Meditation");
                    mTextBoxLeagueName.Focus();
                    return false;
                }

            }

            // Update league properties with form data
            league.Name       = mTextBoxLeagueName.Text.Trim();
            league.Year       = (int)mNumericUpDownSeason.Value;
            league.IsSplit    = mCheckBoxIsSplit.Checked;

            league.WinPoints  = Utils.StringToInt32(mTextBoxWinPoints.Text, 0);
            league.DrawPoints = Utils.StringToInt32(mTextBoxDrawPoints.Text, 0);
            league.LossPoints = Utils.StringToInt32(mTextBoxLossPoints.Text, 0);
            league.TableSort  = (TableSortMethod)mComboBoxTableSort.SelectedIndex;
            league.TableLines = ((mComboBoxLine1.SelectedIndex == 0) ? 0 : (long)Math.Pow(2, mComboBoxLine1.SelectedIndex-1)) | 
                                ((mComboBoxLine2.SelectedIndex == 0) ? 0 : (long)Math.Pow(2, mComboBoxLine2.SelectedIndex-1)) | 
                                ((mComboBoxLine3.SelectedIndex == 0) ? 0 : (long)Math.Pow(2, mComboBoxLine3.SelectedIndex-1)) | 
                                ((mComboBoxLine4.SelectedIndex == 0) ? 0 : (long)Math.Pow(2, mComboBoxLine4.SelectedIndex-1));

            // Save the league
            league.Save();

            // If new league -> add teams
            if (mMode == LeagueFormMode.New)
            {
                league.AddTeams(Convert.ToInt32(mTextBoxTeamCount.Text));
            }

            // Store the name and season so the league can be displayed
            // after leaving this form
            mSelectedLeagueName = league.Name;
            mSelectedSeason     = league.Season;

            return true;
        }

    }
}
