/*
 * TeamStats by Mats Bovin (tsppc@mbovin.com)
 * v1.3.0 February 2007
 * Copyright (c) 2004-07 Mats Bovin
 *
 * This file is part of TeamStats.
 *
 * TeamStats is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * TeamStats is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with TeamStats; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

using System;
using System.Drawing;
using System.ComponentModel;
using System.Windows.Forms;
using MBovin.TeamStats;
using MBovin.TeamStats.Core;
using MBovin.TeamStats.Util;

namespace MBovin.TeamStats.UI
{
	/// <summary>
	/// This from lets the user change the order of the leagues.
	/// </summary>
	public class LeagueOrderForm : System.Windows.Forms.Form
	{
        private ListBox mListBoxLeagues;
        private Button  mButtonMoveUp;
        private Button  mButtonMoveDown;
        private Button  mButtonClose;

        private AppState mAppState;


        /// <summary>
		/// Constructor.
		/// </summary>
        public LeagueOrderForm(AppState appState)
		{
			mAppState = appState;

            InitializeComponent();
		}

		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
            int screenHeight = Screen.PrimaryScreen.WorkingArea.Height;

            this.mListBoxLeagues = new System.Windows.Forms.ListBox();
            this.mButtonMoveUp = new System.Windows.Forms.Button();
            this.mButtonMoveDown = new System.Windows.Forms.Button();
            this.mButtonClose = new System.Windows.Forms.Button();
            // 
            // listBoxLeagues
            // 
            this.mListBoxLeagues.Parent = this;
            this.mListBoxLeagues.Bounds = new Rectangle(8, 16, 160, screenHeight - 64);
            // 
            // buttonMoveUp
            // 
            this.mButtonMoveUp.Parent = this;
            this.mButtonMoveUp.Bounds = new Rectangle(174, 72, 60, 20);
            this.mButtonMoveUp.Font   = MainForm.cButtonFont;
            this.mButtonMoveUp.Text   = Language.GetString("leagueorderform", "up");
            this.mButtonMoveUp.Click += new System.EventHandler(this.ButtonMoveUp_Click);
            // 
            // buttonMoveDown
            // 
            this.mButtonMoveDown.Parent = this;
            this.mButtonMoveDown.Bounds = new Rectangle(174, 120, 60, 20);
            this.mButtonMoveDown.Font   = MainForm.cButtonFont;
            this.mButtonMoveDown.Text   = Language.GetString("leagueorderform", "down");
            this.mButtonMoveDown.Click += new System.EventHandler(this.ButtonMoveDown_Click);
            // 
            // buttonClose
            // 
            this.mButtonClose.Parent = this;
            this.mButtonClose.Bounds = new Rectangle(8, screenHeight - 36, 60, 20);
            this.mButtonClose.Font   = MainForm.cButtonFont;
            this.mButtonClose.Text   = Language.GetString("leagueorderform", "close");
            this.mButtonClose.DialogResult = DialogResult.OK;
            // 
            // LeagueOrderForm
            // 
            this.Text = Language.GetString("leagueorderform", "title");
        }
		#endregion

        #region Events

        /// <summary>
        /// Intialize the form.
        /// </summary>
        protected override void OnLoad(EventArgs e)
        {
            base.OnLoad(e);
            FillLeagueListBox();
        }

        /// <summary>
        /// Handler for the Up-button. Moves selected team up.
        /// </summary>
        private void ButtonMoveUp_Click(object sender, System.EventArgs e)
        {
            int selIndex = mListBoxLeagues.SelectedIndex;
            if (selIndex > 0)
            {
                object temp = mListBoxLeagues.Items[selIndex];
                mListBoxLeagues.Items[selIndex] = mListBoxLeagues.Items[selIndex - 1];
                mListBoxLeagues.Items[selIndex - 1] = temp;
                mListBoxLeagues.SelectedIndex = selIndex - 1;
            }
        }

        /// <summary>
        /// Handler for the Down-button. Moves selected team down.
        /// </summary>
        private void ButtonMoveDown_Click(object sender, System.EventArgs e)
        {
            int selIndex = mListBoxLeagues.SelectedIndex;
            if ((selIndex > -1) && (selIndex < mListBoxLeagues.Items.Count-1))
            {
                object temp = mListBoxLeagues.Items[selIndex];
                mListBoxLeagues.Items[selIndex] = mListBoxLeagues.Items[selIndex + 1];
                mListBoxLeagues.Items[selIndex + 1] = temp;
                mListBoxLeagues.SelectedIndex = selIndex + 1;
            }
        }

        /// <summary>
        /// Form is closing. Copy the order of the leagues 
        /// in the listbox to appstate.
        /// </summary>
        protected override void OnClosing(CancelEventArgs e)
        {
            int i = 0;
            foreach (string leagueName in mListBoxLeagues.Items)
            {
                mAppState.LeagueNames[i++] = leagueName;
            }
            
            base.OnClosing(e);
        }

        #endregion

    
        /// <summary>
        /// Fills the league listbox with names from appstate.
        /// </summary>
        private void FillLeagueListBox()
        {
            foreach (string leagueName in mAppState.LeagueNames)
            {
                mListBoxLeagues.Items.Add(leagueName);
            }
        }

    }
}
