/*
 * TeamStats by Mats Bovin (tsppc@mbovin.com)
 * v1.3.0 February 2007
 * Copyright (c) 2004-07 Mats Bovin
 *
 * This file is part of TeamStats.
 *
 * TeamStats is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * TeamStats is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with TeamStats; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

using System;
using System.Drawing;
using System.Windows.Forms;
using MBovin.TeamStats;
using MBovin.TeamStats.Core;
using MBovin.TeamStats.Util;

namespace MBovin.TeamStats.UI
{
	/// <summary>
	/// This class impelements the league page.
	/// </summary>
	public class LeaguePage : PageBase
	{
        // Constants
        private const int cPageHeight   = 212;
        private const int cScrollFactor = 20;

        // Controls
        private VScrollBar mVScrollBar;

        // The data for this page
        LeagueStats mStats;

		
        /// <summary>
        /// Constructor.
        /// </summary>
        public LeaguePage(AppState appState) : base(appState)
		{
            this.Text = Language.GetString("leaguepage", "title");
        }

        #region Events

        /// <summary>
        /// The scrollbar is used.
        /// </summary>
        private void VScrollBar_ValueChanged(object sender, System.EventArgs e)
        {
            Invalidate();
        }

        /// <summary>
        /// Draws the page.
        /// </summary>
        protected override void OnPaint(System.Windows.Forms.PaintEventArgs e)
        {
            int x1 = Language.GetNumber("leaguepage", "x1");
            int x2 = Language.GetNumber("leaguepage", "x2");
            int x3 = Language.GetNumber("leaguepage", "x3");
            int x4 = Language.GetNumber("leaguepage", "x4");
            int y  = 10;
            int ydelta1 = 16;
            int ydelta2 = 19;

            // Create the stats...
            if (mStats == null)
            {
                mStats = new LeagueStats(mAppState.CurrentLeague);
            }

            // ... and display it
            CreateOffscreenBitmap(cPageHeight);

            mOffscreenGraphics.DrawString(Language.GetString("leaguepage", "matchesplayed"), cMainFont, cLabelBrush, x1, y);
            DrawStringRight(mOffscreenGraphics, mStats.Played.ToString(), cMainFont, cDataBrush, x2, y);
            y += ydelta2;

            mOffscreenGraphics.DrawString(Language.GetString("leaguepage", "homewins"), cMainFont, cLabelBrush, x1, y);
            DrawStringRight(mOffscreenGraphics, mStats.HomeWins.ToString(), cMainFont, cDataBrush, x2, y);
            DrawStringRight(mOffscreenGraphics, "(" + mStats.HomeWinPercent.ToString("##0.0%") + ")", cMainFont, cDataBrush, x3, y);
            y += ydelta1;
            mOffscreenGraphics.DrawString(Language.GetString("leaguepage", "draws"), cMainFont, cLabelBrush, x1, y);
            DrawStringRight(mOffscreenGraphics, mStats.Draws.ToString(), cMainFont, cDataBrush, x2, y);
            DrawStringRight(mOffscreenGraphics, "(" + mStats.DrawPercent.ToString("##0.0%") + ")", cMainFont, cDataBrush, x3, y);
            y += ydelta1;
            mOffscreenGraphics.DrawString(Language.GetString("leaguepage", "awaywins"), cMainFont, cLabelBrush, x1, y);
            DrawStringRight(mOffscreenGraphics, mStats.AwayWins.ToString(), cMainFont, cDataBrush, x2, y);
            DrawStringRight(mOffscreenGraphics, "(" + mStats.AwayWinPercent.ToString("##0.0%") + ")", cMainFont, cDataBrush, x3, y);
            y += ydelta2;

            mOffscreenGraphics.DrawString(Language.GetString("leaguepage", "goals"), cMainFont, cLabelBrush, x1, y);
            DrawStringRight(mOffscreenGraphics, mStats.Goals.ToString(), cMainFont, cDataBrush, x2, y);
            DrawStringRight(mOffscreenGraphics, "(" + mStats.GoalAvg.ToString("#0.00") + ")", cMainFont, cDataBrush, x3, y);
            y += ydelta1;
            mOffscreenGraphics.DrawString(Language.GetString("leaguepage", "homegoals"), cMainFont, cLabelBrush, x1, y);
            DrawStringRight(mOffscreenGraphics, mStats.HomeGoals.ToString(), cMainFont, cDataBrush, x2, y);
            DrawStringRight(mOffscreenGraphics, "(" + mStats.HomeGoalAvg.ToString("#0.00") + ")", cMainFont, cDataBrush, x3, y);
            y += ydelta1;
            mOffscreenGraphics.DrawString(Language.GetString("leaguepage", "awaygoals"), cMainFont, cLabelBrush, x1, y);
            DrawStringRight(mOffscreenGraphics, mStats.AwayGoals.ToString(), cMainFont, cDataBrush, x2, y);
            DrawStringRight(mOffscreenGraphics, "(" + mStats.AwayGoalAvg.ToString("#0.00") + ")", cMainFont, cDataBrush, x3, y);
            y += ydelta2;

            mOffscreenGraphics.DrawString(Language.GetString("leaguepage", "frequentresult"), cMainFont, cLabelBrush, x1, y);
            
            Result result;
            string s;
            for (int i = 0; i < 5; i++)
            {
                result = mStats.GetFrequentResult(i);
                if (result != null)
                {
                    s = String.Format("{0}-{1}  {2} {3}", 
                        result.HomeGoals, 
                        result.AwayGoals, 
                        result.Count, 
                        Language.GetString("leaguepage", "times"));
                    mOffscreenGraphics.DrawString(s, cMainFont, cDataBrush, x4, y);
                    y += ydelta1;
                }
            }

            int yOffset = (mVScrollBar != null) ? -(mVScrollBar.Value * cScrollFactor) : 0;
            e.Graphics.DrawImage(mOffscreenBitmap, 0, yOffset);
        }
        
        #endregion

        /// <summary>
        /// Method for building controls.
        /// </summary>
        public override void BuildGui() 
        {
            if (!mIsGuiBuilt)
            {
                // Only display scrollbar if needed
                if (cPageHeight > this.Height)
                {
                    mVScrollBar             = new VScrollBar();
                    mVScrollBar.Parent      = this;
                    mVScrollBar.Bounds      = new Rectangle(232, 0, 8, this.Height);
                    mVScrollBar.Minimum     = 0;
                    mVScrollBar.Maximum     = (cPageHeight - 1) / cScrollFactor;
                    mVScrollBar.LargeChange = this.Height / cScrollFactor;
                    mVScrollBar.ValueChanged += new EventHandler(this.VScrollBar_ValueChanged);
                }
                mIsGuiBuilt = true;
            }
        }

        /// <summary>
        /// Invalidate the data for this page.
        /// </summary>
        public void InvalidateData()
        {
            mStats = null;
        }

        /// <summary>
        /// Method for initializing controls when 
        /// league (or league data) changes.
        /// </summary>
        public override void InitPage() 
        {
            InvalidateData();
            // This call is necessary due to what seems to 
            // be a bug with redrawing tabpages.
            Invalidate();
        }
	}
}
