/*
 * TeamStats by Mats Bovin (tsppc@mbovin.com)
 * v1.3.0 February 2007
 * Copyright (c) 2004-07 Mats Bovin
 *
 * This file is part of TeamStats.
 *
 * TeamStats is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * TeamStats is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with TeamStats; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

using System;
using System.Drawing;
using System.Windows.Forms;
using MBovin.TeamStats;

namespace MBovin.TeamStats.UI
{
	/// <summary>
	/// Abstract class which all the tabe pages inherits from.
	/// </summary>
	public abstract class PageBase : System.Windows.Forms.TabPage
	{
        // Constants used for drawing
        protected static readonly Font cMainFont = new Font("Microsoft Sans Serif", 10, FontStyle.Regular);
        protected static readonly SolidBrush cLabelBrush = new SolidBrush(Color.Black);
        protected static readonly SolidBrush cDataBrush  = new SolidBrush(Color.Blue);
        protected static readonly Pen cLabelPen = new Pen(Color.Black);
        protected static readonly Pen cDataPen  = new Pen(Color.Blue);

        // The current app state
        protected AppState mAppState;
        // Flag to indicate if the gui components have been initialized
        protected bool mIsGuiBuilt = false;
        // Bitmap and graphics for offscreen drawing
        protected Bitmap   mOffscreenBitmap;
        protected Graphics mOffscreenGraphics;


        /// <summary>
        /// Contructor.
        /// </summary>
        protected PageBase(AppState appState)
        {
            mAppState = appState;
        }

        /// <summary>
        /// Abstract method for creating controls.
        /// </summary>
        public abstract void BuildGui();

        /// <summary>
        /// Abstract method for initializing controls when 
        /// league (or league data) changes.
        /// </summary>
        public abstract void InitPage();

        /// <summary>
        /// Creates the offscreen bitmap and graphics 
        /// with same height as this control.
        /// </summary>
        protected void CreateOffscreenBitmap()
        {
            CreateOffscreenBitmap(this.Height);
        }

        /// <summary>
        /// Creates the offscreen bitmap and graphics 
        /// with the specified height.
        /// </summary>
        protected void CreateOffscreenBitmap(int height)
        {
            if (mOffscreenGraphics == null)
            {
                mOffscreenBitmap   = new Bitmap(this.Width, height);
                mOffscreenGraphics = Graphics.FromImage(mOffscreenBitmap);
            }
            mOffscreenGraphics.Clear(Color.White);                
        }

        /// <summary>
        /// Draws a string right justified at x.
        /// </summary>
        protected void DrawStringRight(Graphics g, string s, Font font, Brush brush, int x, int y)
        {
            int width = (int)g.MeasureString(s, font).Width;
            g.DrawString(s, font, brush, (x-width), y);
        }

        /// <summary>
        /// Draws a string centered at x.
        /// </summary>
        protected void DrawStringCenter(Graphics g, string s, Font font, Brush brush, int x, int y)
        {
            int width = (int)g.MeasureString(s, font).Width;
            g.DrawString(s, font, brush, (x-(width/2)), y);
        }

	}
}
