/*
 * TeamStats by Mats Bovin (tsppc@mbovin.com)
 * v1.3.0 February 2007
 * Copyright (c) 2004-07 Mats Bovin
 *
 * This file is part of TeamStats.
 *
 * TeamStats is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * TeamStats is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with TeamStats; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

using System;
using System.Drawing;
using System.Windows.Forms;
using MBovin.TeamStats.Util;

namespace MBovin.TeamStats.UI
{
	/// <summary>
	/// Dialog where the user selects a round.
	/// </summary>
	public class SelectRoundForm : System.Windows.Forms.Form
	{
        // Constants
        private const int cXdelta       = 22;
        private const int cYdelta       = 22;
        private const int cXstart       = 10;
        private const int cYstart       = 25;
        private const int cRoundsPerRow = 10;
        private readonly Font       cMainFont   = new Font("Microsoft Sans Serif", 10, FontStyle.Regular);
        private readonly SolidBrush cLabelBrush = new SolidBrush(Color.Black);
        private readonly SolidBrush cDataBrush  = new SolidBrush(Color.Blue);

        // Controls
        private Button mButtonCancel;

        // The number of rounds
        private int mRoundCount;
        // The round that was selcted in this dialog
        private int mSelectedRound = -1;


        /// <summary>
        /// Contructor.
        /// </summary>
        public SelectRoundForm(int roundCount)
		{
			mRoundCount = roundCount;
            InitializeComponent();
		}

		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
            int screenHeight = Screen.PrimaryScreen.WorkingArea.Height;

            // 
            // buttonCancel
            // 
            this.mButtonCancel = new Button();
            this.mButtonCancel.Parent = this;
            this.mButtonCancel.Bounds = new Rectangle(8, screenHeight - 36, 60, 20);
            this.mButtonCancel.Font   = MainForm.cButtonFont;
            this.mButtonCancel.Text   = Language.GetString("selectroundform", "cancel");
            this.mButtonCancel.DialogResult = DialogResult.Cancel;
            // 
            // SelectRoundForm
            // 
            this.Text = Language.GetString("selectroundform", "title");

        }
		#endregion

        /// <summary>
        /// The round that was selected in this dialog. 
        /// Returns -1 if no round was selected.
        /// </summary>
        public int SelectedRound
        {
            get { return mSelectedRound; }
        }

        /// <summary>
        /// Draws the form.
        /// </summary>
        protected override void OnPaint(PaintEventArgs e)
        {
            int x, y;

            e.Graphics.DrawString(Language.GetString("selectroundform", "selectroundheader"), cMainFont, cLabelBrush, 10, 5);
            
            x = cXstart;
            y = cYstart;
            for (int i = 0; i < mRoundCount; i++)
            {
                e.Graphics.DrawString((i+1).ToString(), cMainFont, cDataBrush, x, y);
                if (((i + 1) % cRoundsPerRow) == 0)
                {
                    x = cXstart;
                    y += cYdelta;
                }
                else
                {
                    x += cXdelta;
                }
            }
        }

        /// <summary>
        /// Handles tapping on the screen.
        /// </summary>
        protected override void OnMouseUp(MouseEventArgs e)
        {
            base.OnMouseUp(e);

            if ((e.X+3 > cXstart) && (e.X+3 < (cXstart+cRoundsPerRow*cXdelta)) && (e.Y+3 > cYstart))
            {
                // Calculate the row and column
                int column = ((e.X+3-cXstart) / cXdelta);
                int row    = ((e.Y+3-cYstart) / cYdelta);

                // Calculate the round
                int round = (row * cRoundsPerRow) + (column + 1);

                // Exit the dialog if the round is sane.
                if (round <= mRoundCount)
                {
                    mSelectedRound = round;
                    DialogResult   = DialogResult.OK;
                }
            }
        }
	}
}
