/*
 * TeamStats by Mats Bovin (tsppc@mbovin.com)
 * v1.3.0 February 2007
 * Copyright (c) 2004-07 Mats Bovin
 *
 * This file is part of TeamStats.
 *
 * TeamStats is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * TeamStats is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with TeamStats; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

using System;
using System.Drawing;
using System.Collections;
using System.Windows.Forms;
using Microsoft.WindowsCE.Forms;
using MBovin.TeamStats;
using MBovin.TeamStats.Core;
using MBovin.TeamStats.Util;

namespace MBovin.TeamStats.UI
{
    /// <summary>
	/// Summary description for TeamForm.
	/// </summary>
	public class TeamForm : System.Windows.Forms.Form
	{
        private System.Windows.Forms.ListBox  mListBoxTeams;
        private System.Windows.Forms.Label    mLabelName;
        private System.Windows.Forms.Label    mLabelPoints;
        private System.Windows.Forms.TextBox  mTextBoxTeamName;
        private System.Windows.Forms.TextBox  mTextBoxPoints;
        private System.Windows.Forms.Button   mButtonSave;
        private System.Windows.Forms.Button   mButtonClose;
        private System.Windows.Forms.MainMenu mMainMenu1;

        private AppState   mAppState;
        private InputPanel mSip;

		/// <summary>
		/// Constructor
		/// </summary>
        public TeamForm(AppState appState)
		{
            mAppState = appState;
            mSip      = new InputPanel();

			InitializeComponent();
		}

		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
            // This dialog need to be at least 244 pixels high
            int screenHeight = Math.Max(Screen.PrimaryScreen.WorkingArea.Height, 244);

            Graphics g = CreateGraphics();
            int width;

            this.mListBoxTeams = new System.Windows.Forms.ListBox();
            this.mLabelName = new System.Windows.Forms.Label();
            this.mLabelPoints = new System.Windows.Forms.Label();
            this.mTextBoxTeamName = new System.Windows.Forms.TextBox();
            this.mTextBoxPoints = new System.Windows.Forms.TextBox();
            this.mButtonSave = new System.Windows.Forms.Button();
            this.mButtonClose = new System.Windows.Forms.Button();
            this.mMainMenu1 = new System.Windows.Forms.MainMenu();
            // 
            // listBoxTeams
            // 
            this.mListBoxTeams.Parent = this;
            this.mListBoxTeams.Bounds = new Rectangle(8, 4, 224, screenHeight - 188);
            this.mListBoxTeams.SelectedIndexChanged += new System.EventHandler(this.ListBoxTeams_SelectedIndexChanged);
            // 
            // labelName
            // 
            this.mLabelName.Parent = this;
            this.mLabelName.Text   = Language.GetString("teamform", "name");
            width = (int)g.MeasureString(this.mLabelName.Text, this.mLabelName.Font).Width + 2;
            this.mLabelName.Bounds = new Rectangle(8, screenHeight - 178, width, 16);
            // 
            // textBoxTeamName
            // 
            this.mTextBoxTeamName.Parent    = this;
            this.mTextBoxTeamName.Bounds    = new Rectangle(this.mLabelName.Right + 2, screenHeight - 181, 98, 20);
            this.mTextBoxTeamName.MaxLength = 10;
            this.mTextBoxTeamName.Text      = "";
            // 
            // labelPoints
            // 
            this.mLabelPoints.Parent = this;
            this.mLabelPoints.Text   = Language.GetString("teamform", "points");
            width = (int)g.MeasureString(this.mLabelPoints.Text, this.mLabelPoints.Font).Width + 2;
            this.mLabelPoints.Bounds = new Rectangle(8, screenHeight - 153, width, 16);
            // 
            // textBoxPoints
            // 
            this.mTextBoxPoints.Parent    = this;
            this.mTextBoxPoints.Bounds    = new Rectangle(this.mLabelPoints.Right + 2, screenHeight - 156, 40, 20);
            this.mTextBoxPoints.MaxLength = 3;
            this.mTextBoxPoints.Text      = "";
            this.mTextBoxPoints.KeyPress += new System.Windows.Forms.KeyPressEventHandler(this.TextBoxPoints_KeyPress);
            // 
            // mButtonSave
            // 
            this.mButtonSave.Parent = this;
            this.mButtonSave.Bounds = new Rectangle(174, screenHeight - 169, 60, 20);
            this.mButtonSave.Font   = MainForm.cButtonFont;
            this.mButtonSave.Text   = Language.GetString("teamform", "save");
            this.mButtonSave.Click += new System.EventHandler(this.ButtonSave_Click);
            // 
            // buttonClose
            // 
            this.mButtonClose.Parent = this;
            this.mButtonClose.Bounds = new Rectangle(8, screenHeight - 130, 60, 20);
            this.mButtonClose.Font   = MainForm.cButtonFont;
            this.mButtonClose.Text   = Language.GetString("teamform", "close");
            this.mButtonClose.DialogResult = DialogResult.OK;
            // 
            // TeamForm
            // 
            this.ClientSize = new System.Drawing.Size(240, screenHeight - 102);
            this.Menu = this.mMainMenu1;
            this.Text = Language.GetString("teamform", "title");
            this.Closing += new System.ComponentModel.CancelEventHandler(this.TeamForm_Closing);
            this.Load    += new System.EventHandler(this.TeamForm_Load);

            g.Dispose();
        }
		#endregion

        #region Events

        /// <summary>
        /// Initialize the form.
        /// </summary>
        private void TeamForm_Load(object sender, System.EventArgs e)
        {
            // We only open the input panel if we're on a 320 high screen
            if (Screen.PrimaryScreen.WorkingArea.Height >= 294)
            {
                mSip.Enabled = true;
            }
            FillTeamListBox();
        }

        /// <summary>
        /// Close the SIP when form closes.
        /// </summary>
        private void TeamForm_Closing(object sender, System.ComponentModel.CancelEventArgs e)
        {
            mSip.Enabled = false;
        }

        /// <summary>
        /// A team is selected in the team listbox.
        /// </summary>
        private void ListBoxTeams_SelectedIndexChanged(object sender, System.EventArgs e)
        {
            if (mListBoxTeams.SelectedIndex > -1)
            {
                // Get the team and display it's name and
                // bonus points in the text boxes.
                Team team            = (Team)mListBoxTeams.SelectedItem;
                mTextBoxTeamName.Text = team.Name;
                mTextBoxPoints.Text   = team.BonusPoints.ToString();
            }
        }

        /// <summary>
        /// The Save button is clicked.
        /// </summary>
        private void ButtonSave_Click(object sender, System.EventArgs e)
        {
            if (mListBoxTeams.SelectedIndex > -1)
            {
                if (mTextBoxTeamName.Text.Trim().Length > 0)
                {
                    // Get the currently selected team and save
                    // the values from the text boxes.
                    Team team        = (Team)mListBoxTeams.SelectedItem;
                    team.Name        = mTextBoxTeamName.Text.Trim();
                    team.BonusPoints = Utils.StringToInt32(mTextBoxPoints.Text, 0);

                    team.Save();

                    // Re-fill the listbox since the alphabetic order may have changed.
                    FillTeamListBox();
                }
                else
                {
                    MessageBox.Show(Language.GetString("teamform", "teamnameempty"), "Guru Meditation");
                    mTextBoxTeamName.Focus();
                }
            }
        }

        /// <summary>
        /// A charcater is entered in the bonus points text box. 
        /// Checks that it's a digit, backspace, or minus (negative points are allowed).
        /// </summary>
        private void TextBoxPoints_KeyPress(object sender, KeyPressEventArgs e)
        {
            if (!(Char.IsDigit(e.KeyChar) || e.KeyChar == 8 || e.KeyChar == '-'))
            {
                e.Handled = true;
            }
        }

        #endregion

        /// <summary>
        /// Fills the listbox with teams.
        /// </summary>
        private void FillTeamListBox()
        {
            League league      = mAppState.CurrentLeague;
            ArrayList teamList = league.GetTeams();

            // Sort the teams alphabetically
            teamList.Sort();
            
            // Clear list and add the teams
            mListBoxTeams.Items.Clear();
            foreach (Team team in teamList)
            {
                mListBoxTeams.Items.Add(team);
            }
            
            // Reset text-boxes since no team is selected
            mTextBoxTeamName.Text = "";
            mTextBoxPoints.Text   = "";
        }
	}
}
