/*
 * TeamStats by Mats Bovin (tsppc@mbovin.com)
 * v1.1.0 December 2004
 * Copyright (c) 2004 Mats Bovin
 *
 * This file is part of TeamStats.
 *
 * TeamStats is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * TeamStats is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with TeamStats; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

using System;
using System.IO;
using System.Xml;

namespace MBovin.TeamStats.Util
{
    /// <summary>
	/// This class handles language strings. Implemented as a singleton.
	/// </summary>
	public class Language
	{
        // The language file
        private const string cLanguageFilename = "language.xml";
        // The singleton instance
        private static Language sInstance = new Language();
        // Holds the language xml file 
        private XmlDocument mLangDoc;


        /// <summary>
        /// Private constructor to avoid instantiation.
        /// </summary>
        private Language() {}

        /// <summary>
        /// Returns the Language instance.
        /// </summary>
        public static Language GetInstance()
        {
            return sInstance;
        }

        /// <summary>
        /// Loads the language file.
        /// </summary>
        public void Load()
        {
            mLangDoc = new XmlDocument();
            mLangDoc.Load(Path.Combine(Utils.AppDirectory, cLanguageFilename));
        }

        /// <summary>
        /// Returns an item from the language file.
        /// </summary>
        public object GetValue(string section, string item)
        {
            try 
            {
                XmlElement sectionNode = (XmlElement)mLangDoc.GetElementsByTagName(section)[0];
                return sectionNode.GetElementsByTagName(item)[0].InnerText;
            }
            catch (NullReferenceException)
            {
                return null;
            }
        }

        /// <summary>
        /// Convenience method that returns a languauge string.
        /// </summary>
        public static string GetString(string section, string item)
        {
            object val = sInstance.GetValue(section, item);
            return (val != null) ? (string)val : "-" + item + "-";
        }

        /// <summary>
        /// Convenience method that returns a number from the languauge file.
        /// Returns 0 if the string isn't found in the file.
        /// </summary>
        public static int GetNumber(string section, string item)
        {
            object val = sInstance.GetValue(section, item);
            return (val != null) ? int.Parse((string)val) : 0;
        }

	}
}

