/*
 * TSCreate by Mats Bovin (tsppc@mbovin.com)
 * v1.0.0 July 2004
 * Copyright (c) 2004 Mats Bovin
 *
 * This file is part of TeamStats.
 *
 * TeamStats is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * TeamStats is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with TeamStats; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

using System;
using System.Collections;
using System.Globalization;
using System.IO;
using System.Text;
using MBovin.TeamStats.Core;

namespace MBovin.TSCreate
{
	/// <summary>
	/// This class reads league data from a semicolon-separated
	/// file with matches.
	/// </summary>
	public class LeagueSKVFile : ILeagueStore
	{
        private ArrayList mTeamList  = new ArrayList();
        private ArrayList mMatchList = new ArrayList();


        /// <summary>
        /// Constructor.
        /// </summary>
		public LeagueSKVFile(string filename)
		{
            LoadFile(filename);
		}
	
        #region ILeagueStore Members

        public void LoadHeader(League league) {}

        public ArrayList LoadTeams(League league)
        {
            return mTeamList;
        }

        public ArrayList LoadMatches(League league)
        {
            return mMatchList;
        }

        public ArrayList LoadMatches(League league, MatchFilter filterMethod, params object[] args)
        {
            return mMatchList;
        }

        public void SaveHeader(League league) {}

        public void SaveTeams(League league, ArrayList listTeams) {}

        public void SaveMatches(League league, ArrayList listMatches) {}

        public void SaveMatch(League league, Match match) {}

        public void SaveTeam(League league, Team team) {}

        #endregion

        /// <summary>
        /// Loads the specified file.
        /// </summary>
        private void LoadFile(string filename)
        {
            StreamReader reader = null;
            try
            {
                reader = new StreamReader(
                    new FileStream(filename, FileMode.Open), new UTF7Encoding());
                int index = 0;
                string line = reader.ReadLine();
                while (line != null)
                {
                    ParseMatch(line, index++);
                    line = reader.ReadLine();
                }
            }
            finally
            {
                if (reader != null) reader.Close();
            }
        }

        /// <summary>
        /// Parses match data from a semicolon-separated string.
        /// </summary>
        private void ParseMatch(string line, int matchIndex)
        {
            string[] arrMatch = line.Split(';');

            int round = int.Parse(arrMatch[0].Trim());

            DateTimeFormatInfo format  = new DateTimeFormatInfo();
            format.FullDateTimePattern = "yyyy-MM-dd";
            DateTime matchDate = DateTime.Parse(arrMatch[1].Trim(), format);

            int homeTeamIndex = GetTeamIndex(arrMatch[2].Trim());
            int awayTeamIndex = GetTeamIndex(arrMatch[3].Trim());
            
            bool isPlayed = (arrMatch.Length > 5) && 
                            (arrMatch[4].Trim().Length > 0) && 
                            (arrMatch[5].Trim().Length > 0);
            
            Match match = new Match(null, round, matchDate, homeTeamIndex, awayTeamIndex);
            if (isPlayed)
            {
                match.HomeGoals = int.Parse(arrMatch[4].Trim());
                match.AwayGoals = int.Parse(arrMatch[5].Trim());
            }

            match.Index = mMatchList.Count;
            mMatchList.Add(match);
        }

        /// <summary>
        /// Returns the index of the specified team. The team is
        /// added to the team array if it didn't already exist there.
        /// </summary>
        private int GetTeamIndex(string teamName)
        {
            foreach (Team team in mTeamList)
            {
                if (team.Name == teamName)
                {
                    return team.Index;
                }
            }

            return AddTeam(teamName);
        }


        /// <summary>
        /// Adds a team to the team array. 
        /// </summary>
        /// <returns>The index of the team.</returns>
        private int AddTeam(string teamName)
        {
            int teamIndex = mTeamList.Count;
            Team team = new Team(null, teamIndex, teamName);
            mTeamList.Add(team);

            return teamIndex;
        }

    }
}
