/*
 * TeamStats by Mats Bovin (tsppc@mbovin.com)
 * v1.0.0 July 2004
 * Copyright (c) 2004 Mats Bovin
 *
 * This file is part of TeamStats.
 *
 * TeamStats is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * TeamStats is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with TeamStats; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

using System;

namespace MBovin.TeamStats.Core
{
	/// <summary>
	/// Implements a Team.
	/// </summary>
	public class Team : IComparable
	{
        private League mLeague;
        private int    mIndex;
        private string mName;
        private int    mBonusPoints;
        private int    mHiddenPoints;
        

        /// <summary>
        /// Contructor
        /// </summary>
        public Team(League league, int index)
        {
            mLeague = league;
            mIndex  = index;
        }

        /// <summary>
        /// Contructor
        /// </summary>
        public Team(League league, int index, string name)
        {
            mLeague = league;
            mIndex  = index;
            mName   = name;
        }

        #region Properties

        public League League
        {
            get { return mLeague; }
        }

        public string Name
        {
            get { return mName; }
            set { mName = value; }
        }

        public int Index
        {
            get { return mIndex; } 
        }

        public int BonusPoints
        {
            get { return mBonusPoints; }
            set { mBonusPoints = value; }
        }

        public int HiddenPoints
        {
            get { return mHiddenPoints; }
            set { mHiddenPoints = value; }
        }

        #endregion

        /// <summary>
        /// Saves the team data.
        /// </summary>
        public void Save()
        {
            mLeague.LeagueStore.SaveTeam(mLeague, this);
        }

        #region IComparable Members

        /// <summary>
        /// Compares this team to another. Used by Array.Sort().
        /// </summary>
        public int CompareTo(object obj)
        {
            return mName.CompareTo(((Team)obj).mName);
        }

        #endregion

        /// <summary>
        /// Returns the name of the team.
        /// </summary>
        public override string ToString()
        {
            return this.Name;
        }


    }

}
