/*
 * TSCreate by Mats Bovin (tsppc@mbovin.com)
 * v1.0.0 July 2004
 * Copyright (c) 2004 Mats Bovin
 *
 * This file is part of TeamStats.
 *
 * TeamStats is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * TeamStats is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with TeamStats; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

using System;
using System.Collections.Specialized;
using System.IO;
using System.Text;

namespace MBovin.TSCreate
{
	/// <summary>
	/// The main class of the command line version of TSCreate.
	/// </summary>
	class TSCreateCmd
	{
        /// <summary>
        /// Converts a table sort string constant to an index.
        /// </summary>
        private static int GetTableSortIndex(string tableSort)
        {
            int tableSortIndex = 0;
            string[] tableSortConstants = { 
                "goaldiff_goalsfor", 
                "goaldiff_wins", 
                "wins_goaldiff", 
                "wins_goalsfor", 
                "goalsfor_goaldiff", 
                "goalsfor_wins" };
            
            for (int i = 0; i < tableSortConstants.Length; i++)
            {
                if (tableSortConstants[i] == tableSort)
                {
                    tableSortIndex = i;
                    break;
                }
            }
            
            return tableSortIndex;
        }

        /// <summary>
        /// Reads params from the specified file.
        /// </summary>
        private static NameValueCollection GetParameters(string filename)
        {
            NameValueCollection props = new NameValueCollection();
            
            StreamReader reader = null;
            try
            {
                reader = new StreamReader(
                    new FileStream(filename, FileMode.Open), new UTF7Encoding());

                string[] arrLine;
                string   name, val;
                string   line = reader.ReadLine();

                while (line != null)
                {
                    if (line.Trim().Length > 0)
                    {
                        arrLine = line.Split('=');
                        name    = arrLine[0].Trim().ToLower();
                        val     = arrLine[1].Trim();
                        if (name == "tablesort")
                        {
                            val = GetTableSortIndex(val).ToString();
                        }
                        props.Add(name, val);
                    }
                    line = reader.ReadLine();
                }
            }
            finally
            {
                if (reader != null) reader.Close();
            }       

            return props;
        }

	
        /// <summary>
		/// The main entry point for the application.
		/// </summary>
		[STAThread]
		static void Main(string[] args)
		{
            Console.WriteLine("TSCreateCmd v1.0\n");

            if (args.Length == 0)
            {
                Console.WriteLine("Guru meditation:\nParameter file not specified.");
            }
            else
            {
                TSFile tsFile = new TSFile();
                try
                {
                    tsFile.LoadData(GetParameters(args[0]));
                    tsFile.Save();

                    if (tsFile.Warnings.Length > 0)
                    {
                        string msgText = "The file was created but the following warnings were generated:\n";
                        foreach (string s in tsFile.Warnings)
                        {
                            msgText += (s + "\n");
                        }
                        Console.Write(msgText);
                    }

                    Console.WriteLine("Created " + tsFile.GetDefaultFilename());
                }
                catch (Exception e)
                {
                    Console.WriteLine("Guru meditation:\n" + e.Message);
                }
            }
		}

	}
}
