/*
 * TeamStats by Mats Bovin (tsppc@mbovin.com)
 * v1.0.0 July 2004
 * Copyright (c) 2004 Mats Bovin
 *
 * This file is part of TeamStats.
 *
 * TeamStats is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * TeamStats is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with TeamStats; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

using System;
using System.Text;

namespace MBovin.TeamStats.Util
{
	/// <summary>
	/// This class contains various static helper methods.
	/// </summary>
	public class Utils
	{
        /// <summary>
        /// Returns an Utf-8 encoded byte array of s.
        /// If s is longer than 'length' it is truncated.
        /// The size of the byte array is always length * 4
        /// </summary>
        public static byte[] GetUtf8Bytes(string s, int length)
        {
            if (s.Length > length)
            {
                s = s.Substring(0, length);
            }
            byte[] tmpBytes = new UTF8Encoding().GetBytes(s);
            // Create a new byte array of the correct size and copy into it
            byte[] bytes    = new byte[length * 4];
            tmpBytes.CopyTo(bytes, 0);

            return bytes;
        }

        /// <summary>
        /// Parses s using the Convert.ToInt32()-method. If that triggers 
        /// a FormatException, the defaultValue is returned.
        /// </summary>
        public static int StringToInt32(string s, int defaultValue)
        {
            try 
            {
                return Convert.ToInt32(s);
            }
            catch (FormatException) 
            {
                return defaultValue;
            }
        }

	}
}
